<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mediabox?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// M
	'mediabox_description' => 'Par défaut hunn all Linken op Biller (mat Attribut mime/type) a Linke mat der Klass <code>.mediabox</code> Zougrëff op d’Mediabox.

All Link ka mat zousätzleche Klassen agestallt ginn:
-* <code>boxIframe</code> de Link soll an engem Iframe opgemach ginn;
-* <code>boxWidth-350px</code> d’Box soll eng Breet vun 350 Pixel hun;
-* <code>boxHeight-90pc</code> d’Box soll eng Héicht vun 90% hun.

D’Astellung erlaabt de generelle Layout festzeleen, op Basis vun e puer Virlagen.
Dëse Plugin fonktionnéiert mat Skeletter déi den Tag <code>#INSERT_HEAD</code> hun.',
	'mediabox_nom' => 'MediaBox',
	'mediabox_slogan' => 'Mediabox',
];
